==> gcc-java-3.2.1.tar.gz: gcc-3.2.1/libjava/java/io/UTFDataFormatException.java <==
/* UTFDataFormatException.java -- Bad format in UTF data
   Copyright (C) 1998, 1999, 2001 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.
 
GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package java.io;

/* Written using "Java Class Libraries", 2nd edition, ISBN 0-201-31002-3
 * "The Java Language Specification", ISBN 0-201-63451-1
 * Status:  Complete to 1.1.
 */

/**
  * When reading a UTF string from an input stream, this exception is thrown
  * to indicate that the data read is invalid.
  *
  * @version 0.0
  *
  * @author Aaron M. Renn (arenn@urbanophile.com)
  * @author Tom Tromey <tromey@cygnus.com>
  * @date September 24, 1998
  */
public class UTFDataFormatException extends IOException
{

/*
 * Constructors
 */

/**
  * Create a new UTFDataFormatException without a descriptive error message
  */
public
UTFDataFormatException()
{
  super();
}

/*************************************************************************/

/**
  * Create a new UTFDataFormatException with a descriptive error message String
  *
  * @param message The descriptive error message
  */
public
UTFDataFormatException(String message)
{
  super(message);
}

} // class UTFDataFormatException

==> gcc-java-4.0.3.tar.gz: gcc-4.0.3/libjava/java/io/UTFDataFormatException.java <==
/* UTFDataFormatException.java -- thrown on bad format in UTF data
   Copyright (C) 1998, 1999, 2001, 2002, 2005  Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package java.io;

/**
 * When reading a UTF string from an input stream, this exception is thrown
 * to indicate that the data read is invalid.
 *
 * @author Aaron M. Renn (arenn@urbanophile.com)
 * @author Tom Tromey (tromey@cygnus.com)
 * @see DataInput
 * @see DataInputStream#readUTF(DataInput)
 * @status updated to 1.4
 */
public class UTFDataFormatException extends IOException
{
  /**
   * Compatible with JDK 1.0+.
   */
  private static final long serialVersionUID = 420743449228280612L;

  /**
   * Create a new UTFDataFormatException without a descriptive error message.
   */
  public UTFDataFormatException()
  {
  }

  /**
   * Create a new UTFDataFormatException with a descriptive error message.
   *
   * @param message the descriptive error message
   */
  public UTFDataFormatException(String message)
  {
    super(message);
  }
} // class UTFDataFormatException
